! CMD Version:2
! Version 2 enables expanded acceptable characters for object names.
! If unspecified, set to 1 or set to an invalid value, Adams View assumes traditional naming requirements.
!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!------------------------------ Adams View Model ------------------------------!
!
!
model create  &
   model_name = MODEL_1
!
view erase
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .MODEL_1.steel  &
   adams_id = 1  &
   density = 7.801E-06  &
   youngs_modulus = 2.07E+05  &
   poissons_ratio = 0.29
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .MODEL_1.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .MODEL_1.ground.MARKER_2  &
   adams_id = 2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .MODEL_1.ground.MARKER_6  &
   adams_id = 6  &
   location = 150.0, 250.0, 100.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .MODEL_1.ground.MARKER_9  &
   adams_id = 9  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .MODEL_1.ground  &
   material_type = .MODEL_1.steel
!
part attributes  &
   part_name = .MODEL_1.ground  &
   name_visibility = off
!
!----------------------------------- PART_2 -----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .MODEL_1.ground
!
part create rigid_body name_and_position  &
   part_name = .MODEL_1.PART_2  &
   adams_id = 2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .MODEL_1.PART_2
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .MODEL_1.PART_2.MARKER_1  &
   adams_id = 1  &
   location = 0.0, 200.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .MODEL_1.PART_2.cm  &
   adams_id = 7  &
   location = 150.0, 250.0, 100.0  &
   orientation = 90.0d, 90.0d, 0.0d
!
marker create  &
   marker_name = .MODEL_1.PART_2.MARKER_5  &
   adams_id = 5  &
   location = 150.0, 250.0, 100.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .MODEL_1.PART_2.MARKER_8  &
   adams_id = 8  &
   location = 150.0, 250.0, 100.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .MODEL_1.PART_2  &
   material_type = .MODEL_1.steel
!
! ****** Graphics for current part ******
!
geometry create shape block  &
   block_name = .MODEL_1.PART_2.BOX_1  &
   adams_id = 1  &
   corner_marker = .MODEL_1.PART_2.MARKER_1  &
   diag_corner_coords = 300.0, 100.0, 200.0
!
part attributes  &
   part_name = .MODEL_1.PART_2  &
   color = RED  &
   name_visibility = off
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint spherical  &
   joint_name = .MODEL_1.JOINT_1  &
   adams_id = 1  &
   i_marker_name = .MODEL_1.PART_2.MARKER_5  &
   j_marker_name = .MODEL_1.ground.MARKER_6
!
constraint attributes  &
   constraint_name = .MODEL_1.JOINT_1  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .MODEL_1.Last_Sim  &
   commands =   &
              "simulation single_run transient type=auto_select initial_static=no end_time=3.0 step_size=1.0E-02 model_name=.MODEL_1"
!
!-------------------------- Adams View UDE Instances --------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .MODEL_1.ground
!
undo begin_block suppress = yes
!
ude create instance  &
   instance_name = .MODEL_1.MOTION_2  &
   definition_name = .MDI.Constraints.general_motion  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.i_marker  &
   object_value = .MODEL_1.PART_2.MARKER_8
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.j_marker  &
   object_value = .MODEL_1.ground.MARKER_9
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.constraint  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t1_type  &
   integer_value = 0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t2_type  &
   integer_value = 0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t3_type  &
   integer_value = 0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r1_type  &
   integer_value = 1
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r2_type  &
   integer_value = 1
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r3_type  &
   integer_value = 1
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t1_func  &
   string_value = "0 * time"
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t2_func  &
   string_value = "0 * time"
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t3_func  &
   string_value = "0 * time"
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r1_func  &
   string_value = "step(time,0,0,1,45d)"
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r2_func  &
   string_value = "step(time,1,0,2,45d)"
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r3_func  &
   string_value = "step(time,2,0,3,45d)"
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t1_ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t2_ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t3_ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r1_ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r2_ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r3_ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t1_ic_velo  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t2_ic_velo  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.t3_ic_velo  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r1_ic_velo  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r2_ic_velo  &
   real_value = 0.0
!
variable modify  &
   variable_name = .MODEL_1.MOTION_2.r3_ic_velo  &
   real_value = 0.0
!
ude modify instance  &
   instance_name = .MODEL_1.MOTION_2
!
undo end_block
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9806.65  &
   z_component_gravity = 0.0
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------- Function definitions ----------------------------!
!
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .MODEL_1.MOTION_2
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
geometry modify shape block  &
   block_name = .MODEL_1.PART_2.BOX_1  &
   diag_corner_coords =   &
      (300.0mm),  &
      (100.0mm),  &
      (200.0mm)
!
material modify  &
   material_name = .MODEL_1.steel  &
   density = (7801.0(kg/meter**3))  &
   youngs_modulus = (2.07E+11(Newton/meter**2))
!
model display  &
   model_name = MODEL_1
